==> zwap_design_system-0.1.105.tar.gz: lib/organism/navigation/navBar/zwapNavBar.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:zwap_utils/zwap_utils.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';
import 'package:zwap_design_system/molecules/molecules.dart';

/// It handles the state for this custom navBar
class ZwapNavBarState extends ChangeNotifier {

  /// Current selected item
  String selectedItem;

  /// Custom callBack function to handle the change screen on click on any item inside the navBar
  final Function(String newItem) changeScreenCallBack;

  /// Callback function to handle the opening menu
  final Function() openMenuCallBack;

  ZwapNavBarState({
    required this.selectedItem,
    required this.changeScreenCallBack,
    required this.openMenuCallBack
  });

  /// Flag to check if the menu is open
  bool isOpen = false;

  /// It opens or closes the menu
  void openCloseMenu(bool newValue) {
    this.openMenuCallBack();
    this.isOpen = newValue;
    notifyListeners();
  }

  /// It changes the current selected item
  void changeItem(String newValue) {
    this.selectedItem = newValue;
    notifyListeners();
    this.changeScreenCallBack(newValue);
  }
}

/// Component to rendering a navBar with a standard style
class ZwapNavBar extends StatelessWidget {

  /// The icons mapping with their related name inside the navbar menu
  final Map<String, IconData> iconsMenu;

  /// The current avatar image path
  final String currentAvatarPath;

  /// Is this avatar image an external asset?
  final bool isAvatarImageExternal;

  /// Function to handle the click on invite button inside the navBar
  final Function() onInviteButtonClick;

  /// Function to handle the avatar button click
  final Function() onAvatarButtonClick;

  /// The background color for this navbar
  final Color backgroundColor;

  /// Bool flag to show or not the invite button inside the navBar
  final bool showInviteButton;

  ZwapNavBar({Key? key,
    required this.iconsMenu,
    required this.currentAvatarPath,
    required this.backgroundColor,
    required this.onInviteButtonClick,
    required this.onAvatarButtonClick,
    this.isAvatarImageExternal = true,
    this.showInviteButton = false,
  }) : super(key: key);

  /// It retrieves the row to display the icon menu inside the navbar
  Widget _getIconsRow() {
    return Consumer<ZwapNavBarState>(
      builder: (context, provider, child){
        return Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: List<Widget>.generate(this.iconsMenu.keys.toList().length, ((item) => Flexible(
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: Column(
                children: [
                  Padding(
                    padding: EdgeInsets.only(bottom: 1.5),
                    child: InkWell(
                      onTap: () => provider.changeItem(this.iconsMenu.keys.toList()[item]),
                      child: Icon(
                        this.iconsMenu[this.iconsMenu.keys.toList()[item]],
                        color: provider.selectedItem == this.iconsMenu.keys.toList()[item]
                            ? ZwapColors.primary700
                            : ZwapColors.neutral500,
                      ),
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 1.5),
                    child: InkWell(
                      onTap: () => provider.changeItem(this.iconsMenu.keys.toList()[item]),
                      child: ZwapText(
                        text: this.iconsMenu.keys.toList()[item],
                        textColor: provider.selectedItem == this.iconsMenu.keys.toList()[item]
                            ? ZwapColors.primary700
                            : ZwapColors.neutral500,
                        zwapTextType: ZwapTextType.body3Regular,
                      ),
                    ),
                  )
                ],
              ),
            ),
            flex: 0,
            fit: FlexFit.tight,
          ))),
        );
      }
    );
  }

  /// It retrieves the avatar icon with a button to show a dropdown menu
  Widget _getAvatarIcon() {
    return InkWell(
      onTap: () => {},
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Flexible(
            child: ZwapAvatar(
              imagePath: this.currentAvatarPath,
              size: 20,
              isExternal: this.isAvatarImageExternal,
            ),
            flex: 0,
            fit: FlexFit.tight,
          ),
          Flexible(
            child: Consumer<ZwapNavBarState>(
              builder: (context, provider, child){
                return Icon(
                  provider.isOpen
                      ? ZwapIcons.icons['arrow_up']
                      : ZwapIcons.icons['arrow_down'],
                );
              }
            ),
            flex: 0,
            fit: FlexFit.tight,
          )
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> leftWidgets = [
      Padding(
        padding: EdgeInsets.only(right: 25),
        child: Image.asset(
          "assets/images/brand/icon.png",
          package: "zwap_design_system",
          width: 36,
          height: 36,
        ),
      )
    ];
    if (this.showInviteButton) {
      leftWidgets.add(
          Padding(
            padding: EdgeInsets.only(left: 25),
            child: ZwapButton(
              onPressedCallBack: () => this.onInviteButtonClick(),
              zwapButtonContentType: ZwapButtonContentType.withIcon,
              zwapButtonStatus: ZwapButtonStatus.hoverStatus,
              textColor: ZwapColors.neutral600,
              zwapButtonType: ZwapButtonType.flat,
              text: Utils.translatedText("button_invite_navbar"),
              icon: ZwapIcons.icons['invite_nav'],
            ),
          )
      );
    }
    return Container(
      color: this.backgroundColor,
      padding: EdgeInsets.symmetric(vertical: 15, horizontal: 200),
      child: ZwapSeparatedRow(
        crossAxisAlignment: CrossAxisAlignment.center,
        leftWidgets: leftWidgets,
        rightWidgets: [
          Padding(
            padding: EdgeInsets.only(right: 15),
            child: this._getIconsRow(),
          ),
          Padding(
            padding: EdgeInsets.only(left: 15),
            child: this._getAvatarIcon(),
          )
        ],
      ),
    );
  }
}

==> zwap_design_system-0.1.106.tar.gz: lib/organism/navigation/navBar/zwapNavBar.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:zwap_utils/zwap_utils.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';
import 'package:zwap_design_system/molecules/molecules.dart';

/// It handles the state for this custom navBar
class ZwapNavBarState extends ChangeNotifier {

  /// Current selected item
  String selectedItem;

  /// Custom callBack function to handle the change screen on click on any item inside the navBar
  final Function(String newItem) changeScreenCallBack;

  /// Callback function to handle the opening menu
  final Function() openMenuCallBack;

  ZwapNavBarState({
    required this.selectedItem,
    required this.changeScreenCallBack,
    required this.openMenuCallBack
  });

  /// Flag to check if the menu is open
  bool isOpen = false;

  /// It opens or closes the menu
  void openCloseMenu(bool newValue) {
    this.openMenuCallBack();
    this.isOpen = newValue;
    notifyListeners();
  }

  /// It changes the current selected item
  void changeItem(String newValue) {
    this.selectedItem = newValue;
    notifyListeners();
    this.changeScreenCallBack(newValue);
  }
}

/// Component to rendering a navBar with a standard style
class ZwapNavBar extends StatelessWidget {

  /// The icons mapping with their related name inside the navbar menu
  final Map<String, IconData> iconsMenu;

  /// The current avatar image path
  final String currentAvatarPath;

  /// Is this avatar image an external asset?
  final bool isAvatarImageExternal;

  /// Function to handle the click on invite button inside the navBar
  final Function() onInviteButtonClick;

  /// Function to handle the avatar button click
  final Function() onAvatarButtonClick;

  /// The background color for this navbar
  final Color backgroundColor;

  /// Bool flag to show or not the invite button inside the navBar
  final bool showInviteButton;

  ZwapNavBar({Key? key,
    required this.iconsMenu,
    required this.currentAvatarPath,
    required this.backgroundColor,
    required this.onInviteButtonClick,
    required this.onAvatarButtonClick,
    this.isAvatarImageExternal = true,
    this.showInviteButton = false,
  }) : super(key: key);

  /// It retrieves the row to display the icon menu inside the navbar
  Widget _getIconsRow() {
    return Consumer<ZwapNavBarState>(
      builder: (context, provider, child){
        return Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: List<Widget>.generate(this.iconsMenu.keys.toList().length, ((item) => Flexible(
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: Column(
                children: [
                  Padding(
                    padding: EdgeInsets.only(bottom: 1.5),
                    child: InkWell(
                      onTap: () => provider.changeItem(this.iconsMenu.keys.toList()[item]),
                      child: Icon(
                        this.iconsMenu[this.iconsMenu.keys.toList()[item]],
                        color: provider.selectedItem == this.iconsMenu.keys.toList()[item]
                            ? ZwapColors.primary700
                            : ZwapColors.neutral500,
                      ),
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 1.5),
                    child: InkWell(
                      onTap: () => provider.changeItem(this.iconsMenu.keys.toList()[item]),
                      child: ZwapText(
                        text: this.iconsMenu.keys.toList()[item].capitalize(),
                        textColor: provider.selectedItem == this.iconsMenu.keys.toList()[item]
                            ? ZwapColors.primary700
                            : ZwapColors.neutral500,
                        zwapTextType: ZwapTextType.body3Regular,
                      ),
                    ),
                  )
                ],
              ),
            ),
            flex: 0,
            fit: FlexFit.tight,
          ))),
        );
      }
    );
  }

  /// It retrieves the avatar icon with a button to show a dropdown menu
  Widget _getAvatarIcon() {
    return InkWell(
      onTap: () => {},
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Flexible(
            child: ZwapAvatar(
              imagePath: this.currentAvatarPath,
              size: 20,
              isExternal: this.isAvatarImageExternal,
            ),
            flex: 0,
            fit: FlexFit.tight,
          ),
          Flexible(
            child: Consumer<ZwapNavBarState>(
              builder: (context, provider, child){
                return Icon(
                  provider.isOpen
                      ? ZwapIcons.icons['arrow_up']
                      : ZwapIcons.icons['arrow_down'],
                );
              }
            ),
            flex: 0,
            fit: FlexFit.tight,
          )
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> leftWidgets = [
      Padding(
        padding: EdgeInsets.only(right: 25),
        child: Image.asset(
          "assets/images/brand/icon.png",
          package: "zwap_design_system",
          width: 36,
          height: 36,
        ),
      )
    ];
    if (this.showInviteButton) {
      leftWidgets.add(
          Padding(
            padding: EdgeInsets.only(left: 25),
            child: ZwapButton(
              iconColor: ZwapColors.error400,
              onPressedCallBack: () => this.onInviteButtonClick(),
              zwapButtonContentType: ZwapButtonContentType.withIcon,
              zwapButtonStatus: ZwapButtonStatus.hoverStatus,
              textColor: ZwapColors.neutral600,
              zwapButtonType: ZwapButtonType.flat,
              text: Utils.translatedText("button_invite_navbar"),
              icon: ZwapIcons.icons['invite_nav'],
              verticalPadding: 10,
            ),
          )
      );
    }
    return Container(
      color: this.backgroundColor,
      padding: EdgeInsets.symmetric(vertical: 15, horizontal: 150),
      child: ZwapSeparatedRow(
        crossAxisAlignment: CrossAxisAlignment.center,
        leftWidgets: leftWidgets,
        rightWidgets: [
          Padding(
            padding: EdgeInsets.only(right: 15),
            child: this._getIconsRow(),
          ),
          Padding(
            padding: EdgeInsets.only(left: 15),
            child: this._getAvatarIcon(),
          )
        ],
      ),
    );
  }
}
